from buz.query.middleware.handle_middleware import HandleCallable, HandleMiddleware
from buz.query.middleware.base_handle_middleware import BaseHandleMiddleware
from buz.query.middleware.handle_middleware_chain_resolver import HandleMiddlewareChainResolver

__all__ = ["HandleMiddleware", "HandleCallable", "BaseHandleMiddleware", "HandleMiddlewareChainResolver"]



from abc import ABC, abstractmethod
from typing import Iterable

from buz.event.transactional_outbox import OutboxCriteria, OutboxRecord


class OutboxRecordStreamFinder(ABC):
    @abstractmethod
    def find(self, criteria: OutboxCriteria) -> Iterable[OutboxRecord]:
        pass



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['buz',
 'buz.command',
 'buz.command.middleware',
 'buz.command.sync',
 'buz.event',
 'buz.event.kombu',
 'buz.event.kombu.consume_strategy',
 'buz.event.kombu.execution_strategy',
 'buz.event.kombu.publish_strategy',
 'buz.event.kombu.retry',
 'buz.event.middleware',
 'buz.event.sync',
 'buz.event.transactional_outbox',
 'buz.locator',
 'buz.locator.pypendency',
 'buz.locator.sync',
 'buz.middleware',
 'buz.query',
 'buz.query.middleware',
 'buz.query.sync']

package_data = \
{'': ['*']}

extras_require = \
{':python_full_version < "3.7.0"': ['dataclasses>=0.8,<0.9'],
 'kombu': ['kombu>=4.6.11'],
 'pypendency': ['pypendency>=0.1.0,<0.2.0']}

setup_kwargs = {
    'name': 'buz',
    'version': '1.8.0rc1',
    'description': 'Buz is a set of light, simple and extensible implementations of event, command and query buses.',
    'long_description': '# Buz\n\nBuz is a set of light, simple and extensible implementations of event, command and query buses.\n ',
    'author': 'Luis Pintado Lozano',
    'author_email': 'luis.pintado.lozano@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'extras_require': extras_require,
    'python_requires': '>=3.6.9,<4.0.0',
}


setup(**setup_kwargs)



from buz.query.query import Query
from buz.query.query_response import QueryResponse
from buz.query.query_handler import QueryHandler
from buz.query.base_query_handler import BaseQueryHandler
from buz.query.query_bus import QueryBus


__all__ = ["Query", "QueryResponse", "QueryHandler", "BaseQueryHandler", "QueryBus"]



from abc import ABC
from dataclasses import field, dataclass
from datetime import datetime
from typing import Any, ClassVar
from uuid import uuid4


@dataclass(frozen=True)
class Message(ABC):
    DATE_TIME_FORMAT: ClassVar[str] = "%Y-%m-%d %H:%M:%S.%f"

    id: str = field(init=False, default_factory=lambda: str(uuid4()))
    created_at: str = field(
        init=False, default_factory=lambda: datetime.strftime(datetime.now(), Message.DATE_TIME_FORMAT)
    )

    @classmethod
    def fqn(cls) -> str:
        return f"{cls.__module__}.{cls.__name__}"

    @classmethod
    def restore(cls, **kwargs: Any) -> "Message":  # type: ignore[misc]
        message_id = kwargs.pop("id")
        created_at = kwargs.pop("created_at")

        instance = cls(**kwargs)  # type: ignore

        object.__setattr__(instance, "id", message_id)
        object.__setattr__(instance, "created_at", created_at)
        return instance

    def parsed_created_at(self) -> datetime:
        return datetime.strptime(self.created_at, self.DATE_TIME_FORMAT)
